==> xmgfv1.9.1.tar.gz: xmgf/inc/XmgfDefines.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
#define DOT 99
#define PLUS 98
#define BOX 97
#define TRI 96
#define CROSS 95
#define TEXTLABEL 94
#define FILLEDBOX 93
#define FILLEDTRI 92
#define PTCIRCLE  91
#define FILLEDCIRCLE 90
#define NOTFILLED 0
#define FILLEDCOLOR 1
#define FILLEDHIDDENLINE 2
#define BLACKLINES 3
#define WHITELINES 4
#define FILLEDOPAQUE 5
#define SHADED_FILL 6
#define SHADED_LINES 7
#define DEPTH_CUE_LINES 8
#define DEPTH_CUE_POLYS 9
#define DEPTH_CUE_POINTS 10
#define POINTS_ONLY 11
#define COLOUREDLINES 12
#define COLOUREDOPAQUE 13
#define FILLEDDITHER 14

#define UNDEF_COLOR -99

#define MENU_UD 9
#define MENU_POINT 0
#define MENU_CROSS 4
#define MENU_PLUS 3
#define MENU_BOX 1
#define MENU_TRI 2
#define MENU_FILLEDTRI 7
#define MENU_FILLEDBOX 6
#define MENU_CIRCLE 5
#define MENU_FILLEDCIRCLE 8

#define SAVE_GREY 0
#define SAVE_COLOUR 1
#define SAVE_GREY_PORT 2
#define SAVE_COLOUR_PORT 3
#define SAVE_GREY_LAND 4
#define SAVE_COLOUR_LAND 5
#define SAVE_EPS_PORT 6
#define SAVE_EPS_LAND 7

#define LANDSCAPE 1
#define PORTRAIT 0

#define BACK_GRD_COL 0
#define BACK_GRD_IMG  1
#define DEF_GRD_IMG 2

#define SET_COLOUR 0
#define BACK_COLOUR 1
#define HIGH_COLOUR 2
#define ORIG_COLOUR 3
#define OUTL_COLOUR 4

#define ARDEL 0
#define ARLIN 1
#define ARFILL 2
#define ARPTT 3
#define ARCOL 4
#define ARDRAW 5
#define GENNXT 6
#define GENPRV 7
#define GENDEL 8
#define GENDRW 9
#define SELECTSET 10
#define ITEMBUTT 11
#define HIGHLIGHTBUTT 12
#define ORIGINBUTT 13
#define ORIGINCOLBUTT 14

#define ATTRLINE 0
#define ATTRFILL 1
#define ATTRPONT 2
#define ATTRCOLR 3
#define SELECTCOL 0


#define SAVE_PGM_FILE 0
#define SAVE_XBM_FILE 1
#define SAVE_PBM_FILE 2
#define SAVE_PPM_FILE 3
#define SAVE_PARM_FILE 4
#define SAVE_FIG_FILE 5
#define SAVE_PS_FILE 6
#define SAVE_GIF_FILE 7
#define SAVE_RAS_FILE 8
#define LOAD_PARM_FILE 9
#define SAVE_RAY_FILE 10
#define SAVE_FIGCOL_FILE 11
#define SAVE_PSCOL_FILE 12
#define SAVE_RASCOL_FILE 13
#define LOAD_IMG_FILE 14
#define LOAD_GF_FILE 15
#define APPEND_GF_FILE 16
#define IMPORT_OFF_FILE 17
#define IMPORT_NFF_FILE 18
#define IMPORT_RAY_FILE 19
#define IMPORT_SLA_FILE 20
#define IMPORT_OBJ_FILE 21
#define IMPORT_DXF_FILE 22
#define SAVE_MIF_FILE 23
#define SAVE_EPS_FILE 24
#define IMPORT_IGRIP_FILE 25
#define IMPORT_MINICAD_FILE 26
#define LOAD_CMAP_FILE 41
#define LOAD_GMAP_FILE 42
#define LOAD_ANIM_FILE 43
#define SAVE_ANIM_FILE 44



#define SOLIDLS  0
#define DOTLS    1
#define DASHLS   2

#define DEFAULTCOL 149

#define MAX_FILENAME 500

#ifndef PI
#define PI 3.1415927
#endif

/* AttribDefines */
#define ATLINEWIDTH             0
#define ATLINESTYLE             1
#define ATCOLOR                 2
#define ATFILLSTYLE             3
#define ATPOINTTYPE             4
#define ATPOINTSIZE             5
#define ATPOINTCOLOR            6
#define ATFONT                  7
#define ATFONTSIZE              8
#define ATFONTCOLOR             9
#define ATLOCALXYZ             10
#define ATCIRCLERES            11
#define ATLOCALXROT            12
#define ATLOCALYROT            13
#define ATLOCALZROT            14
#define ATLOCALROTCEN	       15	
#define ATLOCALSCALE	       16	
#define ATSCALEX	       17	
#define ATSCALEY	       18	
#define ATSCALEZ	       19	
#define ATSCALECENXYZ	       20	
#define ATFONTWEIGHT           21
#define ATFONTSLANT            22

/* New for Xmgfv2.0 */
#define ATGLOBALLINEWIDTH	40
#define ATGLOBALLINESTYLE	41
#define ATGLOBALCOLOR		42
#define ATGLOBALFILLSTYLE	43
#define ATGLOBALPOINTTYPE	44
#define ATGLOBALPOINTSIZE	45
#define ATGLOBALPOINTCOLOR	46
#define ATGLOBALCIRCLERES	47
#define ATGLOBALSCALE		48
#define ATGLOBALSCALEX		49
#define ATGLOBALSCALEY		50
#define ATGLOBALSCALEZ		51
#define ATGLOBALSCALECENXYZ	52
#define ATGLOBALXROT		53
#define ATGLOBALYROT		54
#define ATGLOBALZROT		55
#define ATGLOBALROTCEN		56

#define ATTSET 			1
#define ATTITEM 		2

#define VIEW_PERS		0
#define VIEW_ORTH		1
#define VIEW_STEREO		2

#define GREY_CMAP 		0
#define RED_CMAP		1
#define GREEN_CMAP		2
#define BLUE_CMAP		3
#define YELLOW_CMAP		4
#define CYAN_CMAP		5
#define MAGENTA_CMAP		6

#define GREYMAP			0
#define COLOURMAP		1

#define DTOR  			0.017453
#define MAX_TEXT_LENGTH 	30

#define ForFirstNLL_M(list,p_elm,n)\
      for(p_elm=FirstElmLL(list),i=0; i<n; p_elm=NextElmLL(p_elm),i++)
#define sgn(a)   (((a)<(0))  ? (-1):(1))
#define MyXmgfErr(A){fprintf(stderr,"Xmgf Error: %s",(A));}

#define MAX_RESOLUTION 100
#define DEFAULT_RESOLUTION 30

#define GetOption() ((*(*argv+2)!='\0')?*argv+2:(argc--,*++argv))

#define RES 20

/* Standard Defines */
#define NOCOLOR 0
#define COLOR 1
#define COLORSET 2
#define SET 3
#define POLYCOLOR 4

/* General Primitives */
#define NOP 0
#define TEXT 1
#define REP 2
#define ID 3

/* FILL Defines */
#define NOFILL 0
#define FILL 1

/* Resolution */
#define RESOLUTION 30

/* 3D structure defines */
#define CYLN  0
#define TRUNC 1
#define CONE  2
#define CYLNARC  3
#define CONEARC  4
#define TRUNCARC  5

/* Macros */
/* #define Deg2Rad(i) (i*0.017453292) */
#define max(a,b) ((a)>(b)) ? (a):(b)
#define min(a,b) ((a)<(b)) ? (a):(b)


#define LINE                    30
#define LINE3D                  31
#define LINECOL                 32
#define LINE3DCOL               33
#define POINT                   34
#define POINT3D                 35
#define POINTCOL                36
#define POINT3DCOL              37
#define POINTSET                38
#define POINTSET3D              39
#define POINTSETCOL             40
#define POINTSET3DCOL           41
#define POINTDOT                42
#define POINTDOT3D              43
#define POINTDOTCOL             44
#define POINTDOT3DCOL           45
#define POINTBOX                46
#define POINTBOX3D              47
#define POINTBOXCOL             48
#define POINTBOX3DCOL           49
#define POINTCROSS              50
#define POINTCROSS3D            51
#define POINTCROSSCOL           52
#define POINTCROSS3DCOL         53
#define POINTTYPE               54
#define POINTTYPE3D             55
#define POINTTYPECOL            56
#define POINTTYPE3DCOL          57
#define POINTPLUS               58
#define POINTPLUS3D             59
#define POINTPLUSCOL            60
#define POINTPLUS3DCOL          61
#define POLYGON                 62
#define POLYGON3D               63
#define POLYGONCOL              64
#define POLYGON3DCOL            65
#define POLYLINE                66
#define POLYLINE3D              67
#define POLYLINECOL             68
#define POLYLINE3DCOL           69
#define ARC                     70
#define ELLIPSE                 71
#define ELLIPSECOL              72
#define CIRCLE                  73
#define CIRCLECOL               74
#define CIRCLE3D                75
#define CIRCLE3DCOL             76
#define CYLINDER3D              77
#define CYLINDER3DCOL           78
#define TRUNCCYLINDER3D         79
#define TRUNCCYLINDER3DCOL      80
#define CONE3D                  81
#define CONE3DCOL               82
#define BLOCK3D                 83
#define BLOCK3DCOL              84
#define TRUNCBLOCK3D            85
#define TRUNCBLOCK3DCOL         86
#define PYRAMID3D               87
#define PYRAMID3DCOL            88
#define TRIBLOCK3D              89
#define TRIBLOCK3DCOL           90
#define TRITRUNCBLOCK3D         91
#define TRITRUNCBLOCK3DCOL      92
#define TRIPYRAMID3D            93
#define TRIPYRAMID3DCOL         94
#define POINTTRI                95
#define POINTTRI3D              96
#define POINTTRICOL             97
#define POINTTRI3DCOL           98
#define ARCCOL                  99
#define ARC3D                   100
#define ARC3DCOL                101
#define ELLIPSE3D               102
#define ELLIPSE3DCOL            103
#define POLYPOINT               104
#define POLYPOINT3D             105
#define POLYPOINTCOL            106
#define POLYPOINT3DCOL          107
#define TEXT3D                  108
#define TEXT3DCOL               109

/* Version 0.2 Format */

#define OrCYLINDER3D            110
#define OrCYLINDER3DCOL         111
#define OrCONE3D                112
#define OrCONE3DCOL             113
#define OrTRUNCCYLINDER3D       114
#define OrTRUNCCYLINDER3DCOL    115
#define OrBLOCK3D               116
#define OrBLOCK3DCOL            117
#define OrTRUNCBLOCK3D          118
#define OrTRUNCBLOCK3DCOL       119
#define OrPYRAMID3D             120
#define OrPYRAMID3DCOL          121
#define XMGFNULL                122
#define OrTRIBLOCK3D            123
#define OrTRIBLOCK3DCOL         124
#define OrTRITRUNCBLOCK3D       125
#define OrTRITRUNCBLOCK3DCOL    126
#define OrTRIPYRAMID3D          127
#define OrTRIPYRAMID3DCOL       128

#define OrCIRCLE3D              129
#define OrCIRCLE3DCOL           130
#define OrCYLINDER3DARC         131
#define OrCYLINDER3DARCCOL      132
#define OrCONE3DARC             133
#define OrCONE3DARCCOL          134
#define OrTRUNCCYLINDER3DARC    135
#define OrTRUNCCYLINDER3DARCCOL 136
#define CUBOID                  137
#define CUBOIDCOL               138

/* Version 0.6 Format ( Old xgf compatibility stuff ) */

#define DASHLINE                139
#define DASHLINECOL             140
#define DASHLINE3D              141
#define DASHLINE3DCOL           142
#define DOTLINE                 143
#define DOTLINECOL              144
#define DOTLINE3D               145
#define DOTLINE3DCOL            146
#define POLYDASHLINE            147
#define POLYDASHLINECOL         148
#define POLYDASHLINE3D          149
#define POLYDASHLINE3DCOL       150
#define POLYDOTLINE             151
#define POLYDOTLINECOL          152
#define POLYDOTLINE3D           153
#define POLYDOTLINE3DCOL        154
#define SPHERE3D                155
#define SPHERE3DCOL             156
#define TEXT2D                  157
#define TEXT2DCOL               158
#define OrSQUARE3D              159
#define OrSQUARE3DCOL           160
#define POINTCIRCLE             161
#define POINTCIRCLE3D           162
#define POINTCIRCLECOL          163
#define POINTCIRCLE3DCOL        164
#define POINTFBOX		165
#define POINTFBOX3D		166
#define POINTFBOXCOL		167
#define POINTFBOX3DCOL		168
#define POINTFTRI		169
#define POINTFTRI3D		170
#define POINTFTRICOL		171
#define POINTFTRI3DCOL		172
#define POINTFCIRCLE		173
#define POINTFCIRCLE3D		174
#define POINTFCIRCLECOL		175
#define POINTFCIRCLE3DCOL	176
#define INCLUDE			177


#define IDIDENTIFIER            200

#define AXIS_ON_CENTROID 2
#define AXIS_ON_CENTRE 1
#define AXIS_ON_ZERO 0

#define NUM             0
#define STARTX          1
#define STARTY          2
#define STARTZ          3
#define ENDX            4
#define ENDY            5
#define ENDZ            6
#define WIDTH           7
#define HEIGHT          8
#define RADIUS          9
#define X               10
#define Y               11
#define TEXTSEG         12
#define BOTRADIUS       13
#define TOPRADIUS       14
#define XCEN            15
#define YCEN            16
#define ZCEN            17
#define MAJOR           18
#define MINOR           19
#define THETA           20
#define VX              21
#define VY              22
#define VZ              23
#define COLORSTR        24
#define TYPESTR         25
#define STARTANGLE      26
#define ENDANGLE        27
#define ORIGX           28
#define ORIGY           29
#define ORIGZ           30
#define LENGTH          31
#define Z               32
#define REPSTR          33

/* Icons Panel */
#define ICONNUMBER 45
#define PSH 0
#define TOG 1
#define NOPARM 0

#define HELP_MAIN 0
#define HELP_LOAD 1
#define HELP_SAVE 2
#define HELP_PRINT 3

==> xmgfv2.4.tar.gz: xmgf/inc/XmgfDefines.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
#define DOT 99
#define PLUS 98
#define BOX 97
#define TRI 96
#define CROSS 95
#define TEXTLABEL 94
#define FILLEDBOX 93
#define FILLEDTRI 92
#define PTCIRCLE  91
#define FILLEDCIRCLE 90
#define FILLEDSPHERE 89
#define NOTFILLED 0
#define FILLEDCOLOR 1
#define FILLEDHIDDENLINE 2
#define BLACKLINES 3
#define WHITELINES 4
#define FILLEDOPAQUE 5
#define SHADED_FILL 6
#define SHADED_LINES 7
#define DEPTH_CUE_LINES 8
#define DEPTH_CUE_POLYS 9
#define DEPTH_CUE_POINTS 10
#define POINTS_ONLY 11
#define COLOUREDLINES 12
#define COLOUREDOPAQUE 13
#define FILLEDDITHER 14
#define HALOEDLINES 15

#define HALSIZE 4

#define LEFTEYE 0
#define RIGHTEYE 1

#define UNDEF_COLOR -99

#define MENU_UD 10
#define MENU_POINT 0
#define MENU_CROSS 4
#define MENU_PLUS 3
#define MENU_BOX 1
#define MENU_TRI 2
#define MENU_FILLEDTRI 7
#define MENU_FILLEDBOX 6
#define MENU_CIRCLE 5
#define MENU_FILLEDCIRCLE 8
#define MENU_FILLEDSPHERE 9

#define SAVE_GREY 0
#define SAVE_COLOUR 1
#define SAVE_GREY_PORT 2
#define SAVE_COLOUR_PORT 3
#define SAVE_GREY_LAND 4
#define SAVE_COLOUR_LAND 5
#define SAVE_EPS_PORT 6
#define SAVE_EPS_LAND 7

#define LANDSCAPE 1
#define PORTRAIT 0

#define BACK_GRD_COL 0
#define BACK_GRD_IMG  1
#define DEF_GRD_IMG 2

#define SET_COLOUR 0
#define BACK_COLOUR 1
#define HIGH_COLOUR 2
#define ORIG_COLOUR 3
#define OUTL_COLOUR 4
#define HALO_COLOUR 5
#define LEFTEYECOL 6
#define RIGHTEYECOL 7

#define ARDEL 0
#define ARLIN 1
#define ARFILL 2
#define ARPTT 3
#define ARCOL 4
#define ARDRAW 5
#define GENNXT 6
#define GENPRV 7
#define GENDEL 8
#define GENDRW 9
#define SELECTSET 10
#define ITEMBUTT 11
#define HIGHLIGHTBUTT 12
#define ORIGINBUTT 13
#define ORIGINCOLBUTT 14

#define ATTRLINE 0
#define ATTRFILL 1
#define ATTRPONT 2
#define ATTRCOLR 3
#define SELECTCOL 0


#define SAVE_PGM_FILE 0
#define SAVE_XBM_FILE 1
#define SAVE_PBM_FILE 2
#define SAVE_PPM_FILE 3
#define SAVE_PARM_FILE 4
#define SAVE_FIG_FILE 5
#define SAVE_PS_FILE 6
#define SAVE_GIF_FILE 7
#define SAVE_RAS_FILE 8
#define LOAD_PARM_FILE 9
#define SAVE_RAY_FILE 10
#define SAVE_FIGCOL_FILE 11
#define SAVE_PSCOL_FILE 12
#define SAVE_RASCOL_FILE 13
#define LOAD_IMG_FILE 14
#define LOAD_GF_FILE 15
#define APPEND_GF_FILE 16
#define IMPORT_OFF_FILE 17
#define IMPORT_NFF_FILE 18
#define IMPORT_RAY_FILE 19
#define IMPORT_SLA_FILE 20
#define IMPORT_OBJ_FILE 21
#define IMPORT_DXF_FILE 22
#define SAVE_MIF_FILE 23
#define SAVE_EPS_FILE 24
#define IMPORT_IGRIP_FILE 25
#define IMPORT_MINICAD_FILE 26
#define LOAD_CMAP_FILE 41
#define LOAD_GMAP_FILE 42
#define LOAD_ANIM_FILE 43
#define SAVE_ANIM_FILE 44
#define SAVE_PCX_FILE 45
#define SAVE_PICT_FILE 46



#define SOLIDLS  0
#define DOTLS    1
#define DASHLS   2

#define DEFAULTCOL 149

#define MAX_FILENAME 500

#ifndef PI
#define PI 3.1415927
#endif

/* AttribDefines */
#define ATLINEWIDTH             0
#define ATLINESTYLE             1
#define ATCOLOR                 2
#define ATFILLSTYLE             3
#define ATPOINTTYPE             4
#define ATPOINTSIZE             5
#define ATPOINTCOLOR            6
#define ATFONT                  7
#define ATFONTSIZE              8
#define ATFONTCOLOR             9
#define ATLOCALXYZ             10
#define ATCIRCLERES            11
#define ATLOCALXROT            12
#define ATLOCALYROT            13
#define ATLOCALZROT            14
#define ATLOCALROTCEN	       15	
#define ATLOCALSCALE	       16	
#define ATSCALEX	       17	
#define ATSCALEY	       18	
#define ATSCALEZ	       19	
#define ATSCALECENXYZ	       20	
#define ATFONTWEIGHT           21
#define ATFONTSLANT            22

/* New for Xmgfv2.0 */
#define ATGLOBALLINEWIDTH	40
#define ATGLOBALLINESTYLE	41
#define ATGLOBALCOLOR		42
#define ATGLOBALFILLSTYLE	43
#define ATGLOBALPOINTTYPE	44
#define ATGLOBALPOINTSIZE	45
#define ATGLOBALPOINTCOLOR	46
#define ATGLOBALCIRCLERES	47
#define ATGLOBALSCALE		48
#define ATGLOBALSCALEX		49
#define ATGLOBALSCALEY		50
#define ATGLOBALSCALEZ		51
#define ATGLOBALSCALECENXYZ	52
#define ATGLOBALXROT		53
#define ATGLOBALYROT		54
#define ATGLOBALZROT		55
#define ATGLOBALROTCEN		56

#define ATTSET 			1
#define ATTITEM 		2

#define VIEW_PERS		0
#define VIEW_ORTH		1
#define VIEW_STEREO		2

#define GREY_CMAP 		0
#define RED_CMAP		1
#define GREEN_CMAP		2
#define BLUE_CMAP		3
#define YELLOW_CMAP		4
#define CYAN_CMAP		5
#define MAGENTA_CMAP		6

#define GREYMAP			0
#define COLOURMAP		1

#define DTOR  			0.017453
#define MAX_TEXT_LENGTH 	30

#define ForFirstNLL_M(list,p_elm,n)\
      for(p_elm=FirstElmLL(list),i=0; i<n; p_elm=NextElmLL(p_elm),i++)
#define sgn(a)   (((a)<(0))  ? (-1):(1))
#define MyXmgfErr(A){fprintf(stderr,"Xmgf Error: %s",(A));}

#define MAX_RESOLUTION 100
#define DEFAULT_RESOLUTION 30

#define GetOption() ((*(*argv+2)!='\0')?*argv+2:(argc--,*++argv))

#define RES 20

/* Standard Defines */
#define NOCOLOR 0
#define COLOR 1
#define COLORSET 2
#define SET 3
#define POLYCOLOR 4

/* General Primitives */
#define NOP 0
#define TEXT 1
#define REP 2
#define ID 3

/* FILL Defines */
#define NOFILL 0
#define FILL 1

/* Resolution */
#define RESOLUTION 30

/* 3D structure defines */
#define CYLN  0
#define TRUNC 1
#define CONE  2
#define CYLNARC  3
#define CONEARC  4
#define TRUNCARC  5

/* Macros */
/* #define Deg2Rad(i) (i*0.017453292) */
#define max(a,b) ((a)>(b)) ? (a):(b)
#define min(a,b) ((a)<(b)) ? (a):(b)
#define XmgfCeiling(a) ((a)==(int)(a) ? (a) : (a)>0 ? 1+(int)(a) : -(1+(int)(-a)))


#define LINE                    30
#define LINE3D                  31
#define LINECOL                 32
#define LINE3DCOL               33
#define POINT                   34
#define POINT3D                 35
#define POINTCOL                36
#define POINT3DCOL              37
#define POINTSET                38
#define POINTSET3D              39
#define POINTSETCOL             40
#define POINTSET3DCOL           41
#define POINTDOT                42
#define POINTDOT3D              43
#define POINTDOTCOL             44
#define POINTDOT3DCOL           45
#define POINTBOX                46
#define POINTBOX3D              47
#define POINTBOXCOL             48
#define POINTBOX3DCOL           49
#define POINTCROSS              50
#define POINTCROSS3D            51
#define POINTCROSSCOL           52
#define POINTCROSS3DCOL         53
#define POINTTYPE               54
#define POINTTYPE3D             55
#define POINTTYPECOL            56
#define POINTTYPE3DCOL          57
#define POINTPLUS               58
#define POINTPLUS3D             59
#define POINTPLUSCOL            60
#define POINTPLUS3DCOL          61
#define POLYGON                 62
#define POLYGON3D               63
#define POLYGONCOL              64
#define POLYGON3DCOL            65
#define POLYLINE                66
#define POLYLINE3D              67
#define POLYLINECOL             68
#define POLYLINE3DCOL           69
#define ARC                     70
#define ELLIPSE                 71
#define ELLIPSECOL              72
#define CIRCLE                  73
#define CIRCLECOL               74
#define CIRCLE3D                75
#define CIRCLE3DCOL             76
#define CYLINDER3D              77
#define CYLINDER3DCOL           78
#define TRUNCCYLINDER3D         79
#define TRUNCCYLINDER3DCOL      80
#define CONE3D                  81
#define CONE3DCOL               82
#define BLOCK3D                 83
#define BLOCK3DCOL              84
#define TRUNCBLOCK3D            85
#define TRUNCBLOCK3DCOL         86
#define PYRAMID3D               87
#define PYRAMID3DCOL            88
#define TRIBLOCK3D              89
#define TRIBLOCK3DCOL           90
#define TRITRUNCBLOCK3D         91
#define TRITRUNCBLOCK3DCOL      92
#define TRIPYRAMID3D            93
#define TRIPYRAMID3DCOL         94
#define POINTTRI                95
#define POINTTRI3D              96
#define POINTTRICOL             97
#define POINTTRI3DCOL           98
#define ARCCOL                  99
#define ARC3D                   100
#define ARC3DCOL                101
#define ELLIPSE3D               102
#define ELLIPSE3DCOL            103
#define POLYPOINT               104
#define POLYPOINT3D             105
#define POLYPOINTCOL            106
#define POLYPOINT3DCOL          107
#define TEXT3D                  108
#define TEXT3DCOL               109

/* Version 0.2 Format */

#define OrCYLINDER3D            110
#define OrCYLINDER3DCOL         111
#define OrCONE3D                112
#define OrCONE3DCOL             113
#define OrTRUNCCYLINDER3D       114
#define OrTRUNCCYLINDER3DCOL    115
#define OrBLOCK3D               116
#define OrBLOCK3DCOL            117
#define OrTRUNCBLOCK3D          118
#define OrTRUNCBLOCK3DCOL       119
#define OrPYRAMID3D             120
#define OrPYRAMID3DCOL          121
#define XMGFNULL                122
#define OrTRIBLOCK3D            123
#define OrTRIBLOCK3DCOL         124
#define OrTRITRUNCBLOCK3D       125
#define OrTRITRUNCBLOCK3DCOL    126
#define OrTRIPYRAMID3D          127
#define OrTRIPYRAMID3DCOL       128

#define OrCIRCLE3D              129
#define OrCIRCLE3DCOL           130
#define OrCYLINDER3DARC         131
#define OrCYLINDER3DARCCOL      132
#define OrCONE3DARC             133
#define OrCONE3DARCCOL          134
#define OrTRUNCCYLINDER3DARC    135
#define OrTRUNCCYLINDER3DARCCOL 136
#define CUBOID                  137
#define CUBOIDCOL               138

/* Version 0.6 Format ( Old xgf compatibility stuff ) */

#define DASHLINE                139
#define DASHLINECOL             140
#define DASHLINE3D              141
#define DASHLINE3DCOL           142
#define DOTLINE                 143
#define DOTLINECOL              144
#define DOTLINE3D               145
#define DOTLINE3DCOL            146
#define POLYDASHLINE            147
#define POLYDASHLINECOL         148
#define POLYDASHLINE3D          149
#define POLYDASHLINE3DCOL       150
#define POLYDOTLINE             151
#define POLYDOTLINECOL          152
#define POLYDOTLINE3D           153
#define POLYDOTLINE3DCOL        154
#define SPHERE3D                155
#define SPHERE3DCOL             156
#define TEXT2D                  157
#define TEXT2DCOL               158
#define OrSQUARE3D              159
#define OrSQUARE3DCOL           160
#define POINTCIRCLE             161
#define POINTCIRCLE3D           162
#define POINTCIRCLECOL          163
#define POINTCIRCLE3DCOL        164
#define POINTFBOX		165
#define POINTFBOX3D		166
#define POINTFBOXCOL		167
#define POINTFBOX3DCOL		168
#define POINTFTRI		169
#define POINTFTRI3D		170
#define POINTFTRICOL		171
#define POINTFTRI3DCOL		172
#define POINTFCIRCLE		173
#define POINTFCIRCLE3D		174
#define POINTFCIRCLECOL		175
#define POINTFCIRCLE3DCOL	176
#define INCLUDE			177
#define POINTSPHERE		178
#define POINTSPHERE3D		179
#define POINTSPHERECOL		180
#define POINTSPHERE3DCOL	181


#define IDIDENTIFIER            200

#define AXIS_BOX 3
#define AXIS_ON_CENTROID 2
#define AXIS_ON_CENTRE 1
#define AXIS_ON_ZERO 0

#define NUM             0
#define STARTX          1
#define STARTY          2
#define STARTZ          3
#define ENDX            4
#define ENDY            5
#define ENDZ            6
#define WIDTH           7
#define HEIGHT          8
#define RADIUS          9
#define X               10
#define Y               11
#define TEXTSEG         12
#define BOTRADIUS       13
#define TOPRADIUS       14
#define XCEN            15
#define YCEN            16
#define ZCEN            17
#define MAJOR           18
#define MINOR           19
#define THETA           20
#define VX              21
#define VY              22
#define VZ              23
#define COLORSTR        24
#define TYPESTR         25
#define STARTANGLE      26
#define ENDANGLE        27
#define ORIGX           28
#define ORIGY           29
#define ORIGZ           30
#define LENGTH          31
#define Z               32
#define REPSTR          33

/* Icons Panel */
#define ICONNUMBER 45
#define PSH 0
#define TOG 1
#define NOPARM 0

#define HELP_MAIN 0
#define HELP_LOAD 1
#define HELP_SAVE 2
#define HELP_PRINT 3
#define HELP_MOSAIC 4

#define MAX_NUM_XARGS 30
